# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.messaging_profiles import (
    AutoRespConfigResponse,
    AutorespConfigListResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAutorespConfigs:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
            resp_text="Thank you for your message",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.messaging_profiles.autoresp_configs.with_raw_response.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = response.parse()
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.messaging_profiles.autoresp_configs.with_streaming_response.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = response.parse()
            assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_create(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.create(
                profile_id="",
                country_code="US",
                keywords=["keyword1", "keyword2"],
                op="start",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.retrieve(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.messaging_profiles.autoresp_configs.with_raw_response.retrieve(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = response.parse()
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.messaging_profiles.autoresp_configs.with_streaming_response.retrieve(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = response.parse()
            assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.retrieve(
                autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                profile_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `autoresp_cfg_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.retrieve(
                autoresp_cfg_id="",
                profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
            resp_text="Thank you for your message",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.messaging_profiles.autoresp_configs.with_raw_response.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = response.parse()
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.messaging_profiles.autoresp_configs.with_streaming_response.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = response.parse()
            assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.update(
                autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                profile_id="",
                country_code="US",
                keywords=["keyword1", "keyword2"],
                op="start",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `autoresp_cfg_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.update(
                autoresp_cfg_id="",
                profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                country_code="US",
                keywords=["keyword1", "keyword2"],
                op="start",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="country_code",
            created_at={
                "gte": "gte",
                "lte": "lte",
            },
            updated_at={
                "gte": "gte",
                "lte": "lte",
            },
        )
        assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.messaging_profiles.autoresp_configs.with_raw_response.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = response.parse()
        assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.messaging_profiles.autoresp_configs.with_streaming_response.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = response.parse()
            assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_list(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.list(
                profile_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete(self, client: Telnyx) -> None:
        autoresp_config = client.messaging_profiles.autoresp_configs.delete(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(str, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: Telnyx) -> None:
        response = client.messaging_profiles.autoresp_configs.with_raw_response.delete(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = response.parse()
        assert_matches_type(str, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: Telnyx) -> None:
        with client.messaging_profiles.autoresp_configs.with_streaming_response.delete(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = response.parse()
            assert_matches_type(str, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.delete(
                autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                profile_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `autoresp_cfg_id` but received ''"):
            client.messaging_profiles.autoresp_configs.with_raw_response.delete(
                autoresp_cfg_id="",
                profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )


class TestAsyncAutorespConfigs:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
            resp_text="Thank you for your message",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_profiles.autoresp_configs.with_raw_response.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = await response.parse()
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_profiles.autoresp_configs.with_streaming_response.create(
            profile_id="profile_id",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = await response.parse()
            assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_create(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.create(
                profile_id="",
                country_code="US",
                keywords=["keyword1", "keyword2"],
                op="start",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.retrieve(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_profiles.autoresp_configs.with_raw_response.retrieve(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = await response.parse()
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_profiles.autoresp_configs.with_streaming_response.retrieve(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = await response.parse()
            assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.retrieve(
                autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                profile_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `autoresp_cfg_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.retrieve(
                autoresp_cfg_id="",
                profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
            resp_text="Thank you for your message",
        )
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_profiles.autoresp_configs.with_raw_response.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = await response.parse()
        assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_profiles.autoresp_configs.with_streaming_response.update(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="US",
            keywords=["keyword1", "keyword2"],
            op="start",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = await response.parse()
            assert_matches_type(AutoRespConfigResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.update(
                autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                profile_id="",
                country_code="US",
                keywords=["keyword1", "keyword2"],
                op="start",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `autoresp_cfg_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.update(
                autoresp_cfg_id="",
                profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                country_code="US",
                keywords=["keyword1", "keyword2"],
                op="start",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            country_code="country_code",
            created_at={
                "gte": "gte",
                "lte": "lte",
            },
            updated_at={
                "gte": "gte",
                "lte": "lte",
            },
        )
        assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_profiles.autoresp_configs.with_raw_response.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = await response.parse()
        assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_profiles.autoresp_configs.with_streaming_response.list(
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = await response.parse()
            assert_matches_type(AutorespConfigListResponse, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_list(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.list(
                profile_id="",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncTelnyx) -> None:
        autoresp_config = await async_client.messaging_profiles.autoresp_configs.delete(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(str, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.messaging_profiles.autoresp_configs.with_raw_response.delete(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        autoresp_config = await response.parse()
        assert_matches_type(str, autoresp_config, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncTelnyx) -> None:
        async with async_client.messaging_profiles.autoresp_configs.with_streaming_response.delete(
            autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            autoresp_config = await response.parse()
            assert_matches_type(str, autoresp_config, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `profile_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.delete(
                autoresp_cfg_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                profile_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `autoresp_cfg_id` but received ''"):
            await async_client.messaging_profiles.autoresp_configs.with_raw_response.delete(
                autoresp_cfg_id="",
                profile_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .pagination_meta import PaginationMeta
from .push_credential import PushCredential

__all__ = ["MobilePushCredentialListResponse"]


class MobilePushCredentialListResponse(BaseModel):
    """Mobile mobile push credentials"""

    data: Optional[List[PushCredential]] = None

    meta: Optional[PaginationMeta] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from .._types import SequenceNotStr
from .._utils import PropertyInfo

__all__ = ["MessageSendLongCodeParams"]


class MessageSendLongCodeParams(TypedDict, total=False):
    from_: Required[Annotated[str, PropertyInfo(alias="from")]]
    """Phone number, in +E.164 format, used to send the message."""

    to: Required[str]
    """Receiving address (+E.164 formatted phone number or short code)."""

    auto_detect: bool
    """
    Automatically detect if an SMS message is unusually long and exceeds a
    recommended limit of message parts.
    """

    media_urls: SequenceNotStr[str]
    """A list of media URLs. The total media size must be less than 1 MB.

    **Required for MMS**
    """

    subject: str
    """Subject of multimedia message"""

    text: str
    """Message body (i.e., content) as a non-empty string.

    **Required for SMS**
    """

    type: Literal["SMS", "MMS"]
    """The protocol for sending the message, either SMS or MMS."""

    use_profile_webhooks: bool
    """
    If the profile this number is associated with has webhooks, use them for
    delivery notifications. If webhooks are also specified on the message itself,
    they will be attempted first, then those on the profile.
    """

    webhook_failover_url: str
    """
    The failover URL where webhooks related to this message will be sent if sending
    to the primary URL fails.
    """

    webhook_url: str
    """The URL where webhooks related to this message will be sent."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["ConferenceEndedWebhookEvent", "Data", "DataPayload"]


class DataPayload(BaseModel):
    call_control_id: Optional[str] = None
    """Call ID used to issue commands via Call Control API."""

    call_leg_id: Optional[str] = None
    """ID that is unique to the call and can be used to correlate webhook events."""

    call_session_id: Optional[str] = None
    """
    ID that is unique to the call session and can be used to correlate webhook
    events. Call session is a group of related call legs that logically belong to
    the same phone call, e.g. an inbound and outbound leg of a transferred call.
    """

    client_state: Optional[str] = None
    """State received from a command."""

    conference_id: Optional[str] = None
    """Conference ID that the participant joined."""

    connection_id: Optional[str] = None
    """Call Control App ID (formerly Telnyx connection ID) used in the call."""

    occurred_at: Optional[datetime] = None
    """ISO 8601 datetime of when the event occurred."""

    reason: Optional[Literal["all_left", "host_left", "time_exceeded"]] = None
    """Reason the conference ended."""


class Data(BaseModel):
    id: Optional[str] = None
    """Identifies the type of resource."""

    event_type: Optional[Literal["conference.ended"]] = None
    """The type of event being delivered."""

    payload: Optional[DataPayload] = None

    record_type: Optional[Literal["event"]] = None
    """Identifies the type of the resource."""


class ConferenceEndedWebhookEvent(BaseModel):
    data: Optional[Data] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List
from typing_extensions import Literal, TypedDict

__all__ = ["AdditionalDocumentListParams", "Filter", "Page", "Sort"]


class AdditionalDocumentListParams(TypedDict, total=False):
    filter: Filter
    """Consolidated filter parameter (deepObject style).

    Originally: filter[document_type]
    """

    page: Page
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """

    sort: Sort
    """Consolidated sort parameter (deepObject style). Originally: sort[value]"""


class Filter(TypedDict, total=False):
    """Consolidated filter parameter (deepObject style).

    Originally: filter[document_type]
    """

    document_type: List[Literal["loa", "invoice", "csr", "other"]]
    """Filter additional documents by a list of document types"""


class Page(TypedDict, total=False):
    """Consolidated page parameter (deepObject style).

    Originally: page[size], page[number]
    """

    number: int
    """The page number to load"""

    size: int
    """The size of the page"""


class Sort(TypedDict, total=False):
    """Consolidated sort parameter (deepObject style). Originally: sort[value]"""

    value: Literal["created_at", "-created_at"]
    """Specifies the sort order for results.

    If not given, results are sorted by created_at in descending order.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .verified_number import VerifiedNumber

__all__ = ["VerifiedNumberListResponse", "Meta"]


class Meta(BaseModel):
    page_number: Optional[int] = None

    page_size: Optional[int] = None

    total_pages: Optional[int] = None

    total_results: Optional[int] = None


class VerifiedNumberListResponse(BaseModel):
    """A paginated list of Verified Numbers"""

    data: List[VerifiedNumber]

    meta: Meta
